@@ -59,8 +59,8 @@ the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
 // See netfile.c for explanation of delimiters.  'X'
 // separates single-character delimiters from two-character delimiters.
-#define VLOG_DELIMITERS ",;:(){}[]=X///**/#("
-#define VLOG_PIN_NAME_DELIMITERS "()X///**/"
+#define VLOG_DELIMITERS "X///**/#((**)X,::(){}[]="
+#define VLOG_PIN_NAME_DELIMITERS "X///**/(**)X()"
 
 // Global storage for verilog parameters
 struct hashdict verilogparams;
@@ -1062,14 +1062,25 @@ skip_endmodule:
 	}
     }
 
-    else if (match(nexttok, "wire")) {	/* wire = node */
+    else if (match(nexttok, "wire") || match(nexttok, "assign")) {	/* wire = node */
       struct bus wb, *nb;
       char nodename[128];
+      int is_assignment = FALSE;
+      struct objlist *lhs, *rhs;
+
+      // Several allowed uses of "assign":
+      // "assign a = b" joins two nets.
+      // "assign a = {b, c, ...}" creates a bus from components.
+      // "assign" using any boolean arithmetic is not structural verilog.
+
       SkipTokNoNewline(VLOG_DELIMITERS);
       if (match(nexttok, "real")) SkipTokNoNewline(VLOG_DELIMITERS);
       while (nexttok != NULL) {
-	 /* Handle bus notation */
-	 if (GetBusTok(&wb) == 0) {
+	 if (match(nexttok, "=")) {
+	     is_assignment = TRUE;
+	 }
+	 else if (GetBusTok(&wb) == 0) {
+	     /* Handle bus notation */
 	     SkipTokNoNewline(VLOG_DELIMITERS);
 	     if (wb.start > wb.end) {
 		for (i = wb.end; i <= wb.start; i++) {
@@ -1091,10 +1102,28 @@ skip_endmodule:
 	     HashPtrInstall(nexttok, nb, &buses);
 	 }
 	 else {
-	     if (LookupObject(nexttok, CurrentCell) == NULL)
+	     if (is_assignment) {
+		 /* Handle assignment statements */
+		 /* To be done:  Handle where both are bus names, and	*/
+		 /* where lhs is a bus name and rhs is a list of nets	*/
+		 if ((rhs = LookupObject(nexttok, CurrentCell)) != NULL) {
+		     join(lhs->name, rhs->name);
+		 }
+		 else {
+		     Printf("Module '%s' is not structural verilog, "
+				"making black-box.\n", model);
+		     SetClass(CLASS_MODULE);
+		     goto skip_endmodule;
+		 }
+		 is_assignment = FALSE;
+	     }
+	     else if (LookupObject(nexttok, CurrentCell) == NULL)
 	         Node(nexttok);
+		 lhs = LookupObject(nexttok, CurrentCell);
 	 }
-         SkipTokNoNewline(VLOG_DELIMITERS);
+	 do {
+	     SkipTokNoNewline(VLOG_DELIMITERS);
+	 } while (nexttok && match(nexttok, ";"));
       }
     }
     else if (match(nexttok, "endmodule")) {
@@ -1106,8 +1135,7 @@ skip_endmodule:
       // Ignore any other directive starting with a backtick
       SkipNewLine(VLOG_DELIMITERS);
     }
-    else if (match(nexttok, "reg") || match(nexttok, "assign")
-		|| match(nexttok, "always")) {
+    else if (match(nexttok, "reg") || match(nexttok, "always")) {
       Printf("Module '%s' is not structural verilog, making black-box.\n", model);
       // To be done:  Remove any contents (but may not be necessary)
       // Recast as module
@@ -1680,10 +1708,6 @@ char *ReadVerilogTop(char *fname, int *fnum, int blackbox)
   kl->pdefault.ival = 1;
   HashPtrInstall(kl->key, kl, &verilogdefs);
 
-  /* All verilog files should start with a comment line,  */
-  /* but we won't depend upon it.  Any comment line	  */
-  /* will be handled by the main Verilog file processing. */
-
   ReadVerilogFile(fname, filenum, &CellStack, blackbox);
   CloseParseFile();
 
